@@ -53,8 +53,10 @@ class Video:
         file_paths = sorted(file_paths)
         for path in file_paths:
             self.file_path.append(File(path))
-            self.info.subtitle = os.path.splitext(
+            self.info.is_subtitle = os.path.splitext(
                 path)[0].upper().endswith("C")
+            self.info.is_uncensored = (path.upper().find("UNCENSOR") != -1)
+            self.info.is_4K = (path.upper().find("4K") != -1)
 
     def __str__(self):
         ret = "[文件 {0}]".format(
@@ -66,13 +68,14 @@ class Video:
             return ret + str(self.info)
 
     def __gen_file_name(self):
-        if len(self.info.title.encode()) > 200:
+        MAX_LENGTH = 200
+        if len(self.info.title.encode()) > MAX_LENGTH:
             if len(self.info.cast) == 1:
-                overflow = 200 - len(self.info.cast[0].encode())
-                return "{:}.. {:}".format(self.info.title[:overflow // 3], self.info.cast[0])
+                overflow = MAX_LENGTH - len(self.info.cast[0].encode())
+                return strip("{:}.. {:}".format(self.info.title[:overflow // 3], self.info.cast[0]))
             else:
-                overflow = 200
-                return self.info.title[:overflow // 3]
+                overflow = MAX_LENGTH
+                return strip(self.info.title[:overflow // 3])
         else:
             return strip(self.info.title)
 
@@ -93,8 +96,6 @@ class Video:
             print("    Exception: ", str(e))
             print("    ", " ".join([str(file) for file in self.file_path]))
             return
-        if self.info.subtitle:
-            self.info.genres.append("中文字幕")
 
         # Join path (slices)
         if self.slices > 1:
